[Zope3-checkins] CVS: Zope3/src/zope/app/interfaces/browser - form.py:1.8.2.2

Fred L. Drake, Jr. fred@zope.com
Fri, 16 May 2003 15:51:57 -0400


Update of /cvs-repository/Zope3/src/zope/app/interfaces/browser
In directory cvs.zope.org:/tmp/cvs-serv4045

Modified Files:
      Tag: schema-vocabulary-branch
	form.py 
Log Message:
IVocabularyQueryView.setPrefix():  Changed to setName(), since that's
    what we really want to have happen.  If multiple names are needed,
    the query view can use the name as a prefix be appending a dot.


=== Zope3/src/zope/app/interfaces/browser/form.py 1.8.2.1 => 1.8.2.2 ===
--- Zope3/src/zope/app/interfaces/browser/form.py:1.8.2.1	Fri May 16 12:05:14 2003
+++ Zope3/src/zope/app/interfaces/browser/form.py	Fri May 16 15:51:57 2003
@@ -164,11 +164,11 @@
     edit widgets to support query and result presentations.
     """
 
-    def setPrefix(prefix):
-        """Set the prefix used for names of input elements
+    def setName(name):
+        """Set the name used to compute the form field names.
 
-        Element names should begin with the given prefix,
-        followed by a dot.
+        Element names should be the given name, or add additional name
+        components separated by dots.
         """
 
     def renderInput():